@@ -211,6 +211,6 @@ class __TwigTemplate_1db1dadff28a40463927a909bea6e262 extends Template
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@MauticCampaign/Event/_generic.html.twig", "/var/www/html/staging-demo/app/bundles/CampaignBundle/Resources/views/Event/_generic.html.twig");
+        return new Source("", "@MauticCampaign/Event/_generic.html.twig", "/var/www/html/mauticGIT-Test/app/bundles/CampaignBundle/Resources/views/Event/_generic.html.twig");
     }
 }
